Boilerplate library | Plone Intranet

Thank you for using the boilerplate library!
Group by
Expand sidebar Create boilerplate Select
Report A default structure for reports such as management reports and evaluations.
Liz Baker 2000-01-17 00:00:00 +0100
Memo A default structure for short notes, messages and announcements.
Liz Baker 2000-01-17 00:00:00 +0100

- Create document
- Create folder
- Paste
- Change folder name or description
- Upload file(s)
- Select

- Text document
- Slideshow
- Event
- Weblink
- Upload file(s)

Help